## Dataset Loaders and Data Preparation

This module provides all dataset loaders supported in the NN Dataset project. Each loader includes dataset-specific preparation procedures, default normalization parameters, and expected output shape.

Data transformation and normalization algorithms are available in a separate module <a href='../transform'>ab.nn.transform</a>.
